==> python-lectio-unbloated-2.1.2.tar.gz: python-lectio-unbloated-2.1.2/lectio/_modul.py <==
from .imports import *


def modul(self, absid):
    url = f"https://www.lectio.dk/lectio/{self.skoleId}/aktivitet/aktivitetforside2.aspx?absid={absid}"
    resp = self.session.get(url)
    if resp.url != url:
        raise Exception("lectio-cookie udløbet")
    soup = BeautifulSoup(resp.text, "html.parser")

    modulDetaljer = {
        "aktivitet": None,
        "note": "",
        "lektier": "",
        "præsentation": "",
        "øvrigtIndhold": "",
    }

    try:
        modulDetaljer["note"] = soup.find(
            "textarea", {"class": "activity-note"}
        ).text.lstrip()
    except Exception:
        pass

    modulContent = soup.find(
        "div", {"id": "s_m_Content_Content_tocAndToolbar_inlineHomeworkDiv"}
    )
    last = ""
    for div in modulContent.find_all("div"):
        if div.get("id") == None:
            if (
                divText := div.text.lstrip().rstrip()
            ) != "" and divText != "Vis fuld skærm":
                last = divText.lower().title().replace(" ", "")
                last = last[0].lower() + last[1:]
        else:
            for element in str(div).replace("\xa0", "\n").split("\n"):
                elementSoup = BeautifulSoup(element, "html.parser")
                if elementSoup.text != "":
                    if (elementWithHref := elementSoup.find("a", href=True)) != None:
                        href = elementWithHref.get("href")
                        if href.startswith(f"/lectio/{self.skoleId}"):
                            href = "https://www.lectio.dk" + href
                        modulDetaljer[last] += unicodedata.normalize(
                            "NFKD", f"[{elementSoup.text.rstrip().lstrip()}]({href})\n"
                        )
                    else:
                        modulDetaljer[last] += unicodedata.normalize(
                            "NFKD",
                            elementSoup.text.rstrip().lstrip().replace("\xa0", " ")
                            + "\n",
                        )

    renameDictionary = {"Lærere": "Lærer", "Lokaler": "Lokale"}

    modulDict = {
        "navn": None,
        "tidspunkt": None,
        "hold": None,
        "lærer": None,
        "lokale": None,
        "absid": absid,
    }
    for modulDetalje in (
        soup.find("a", class_="s2skemabrik")["data-additionalinfo"]
        .split("\n\n")[0]
        .split("\n")
    ):
        if (value := ": ".join(modulDetalje.split(": ")[1:])) != "":
            if (navn := modulDetalje.split(": ")[0]) in renameDictionary:
                navn = renameDictionary[navn]

            modulDict[navn.lower()] = value
        else:
            try:
                int(
                    datetime.strptime(
                        modulDetalje.split(": ")[0].split(" til")[0], "%d/%m-%Y %H:%M"
                    ).timestamp()
                )
                modulDict["tidspunkt"] = modulDetalje
            except Exception:
                modulDict["navn"] = modulDetalje.split(": ")[0]

    modulDetaljer["aktivitet"] = modulDict

    return modulDetaljer


def elevFeedback():
    pass

==> python-lectio-unbloated-2.1.8.tar.gz: python-lectio-unbloated-2.1.8/lectio/_modul.py <==
from .imports import *
from . import _utils


def modul(self, absid):
    url = f"https://www.lectio.dk/lectio/{self.skoleId}/aktivitet/aktivitetforside2.aspx?absid={absid}"
    resp = self.session.get(url)
    if resp.url != url:
        raise Exception("lectio-cookie udløbet")
    soup = BeautifulSoup(resp.text, "html.parser")

    modulDetaljer = {
        "aktivitet": None,
        "note": "",
        "lektier": "",
        "præsentation": "",
        "øvrigtIndhold": "",
    }

    try:
        modulDetaljer["note"] = soup.find(
            "textarea", {"class": "activity-note"}
        ).text.lstrip()
    except Exception:
        pass

    modulContent = soup.find(
        "div", {"id": "s_m_Content_Content_tocAndToolbar_inlineHomeworkDiv"}
    )
    last = ""
    for div in modulContent.find_all("div"):
        if div.get("id") == None:
            if (
                divText := div.text.lstrip().rstrip()
            ) != "" and divText != "Vis fuld skærm":
                last = divText.lower().title().replace(" ", "")
                last = last[0].lower() + last[1:]
        else:
            for element in str(div).replace("\xa0", "\n").split("\n"):
                elementSoup = BeautifulSoup(element, "html.parser")
                if elementSoup.text != "":
                    if (elementWithHref := elementSoup.find("a", href=True)) != None:
                        href = elementWithHref.get("href")
                        if href.startswith(f"/lectio/{self.skoleId}"):
                            href = "https://www.lectio.dk" + href
                        modulDetaljer[last] += unicodedata.normalize(
                            "NFKD", f"[{elementSoup.text.rstrip().lstrip()}]({href})\n"
                        )
                    else:
                        modulDetaljer[last] += unicodedata.normalize(
                            "NFKD",
                            elementSoup.text.rstrip().lstrip().replace("\xa0", " ")
                            + "\n",
                        )

    årstal = (
        soup.find("span", {"id": "s_m_masterfooternowSpan"})
        .text.split("  ")[0]
        .split("-")[1]
    )  # Upræcis men virker det meste af tiden
    dato = (
        soup.find("div", {"class": "s2skemabrikcontent"}).text.split(" ")[1]
        + "-"
        + årstal
    )
    modulDetaljer["aktivitet"] = _utils.skemaBrikExtract(
        dato, soup.find("a", class_="s2skemabrik")
    )

    return modulDetaljer


def elevFeedback():
    pass
